package com.kexun.config;

import com.kexun.constant.BaseConsts;
import com.kexun.constant.XmlNodeConsts;
import com.kexun.entity.*;
import com.kexun.factory.HandleXmlFactory;
import com.kexun.factory.HandleXmlFactoryBean;
import com.kexun.model.xml.*;
import com.kexun.model.xml.pub.*;
import com.kexun.model.xml.trs.*;
import com.kexun.service.*;
import com.kexun.service.field.BaseFieldPackageJsonService;
import com.kexun.service.xml.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.HashMap;
import java.util.Map;

/**
 * Description:解析各类报文配置所需要的service,model等信息config
 *
 * @author lgs
 * @date 2023/05/25
 */
@Configuration
public class HandleXmlConfig {


    @Autowired
    CrHeadInfService crHeadInfService;
    @Autowired
    CrHeadOtherIdService crHeadOtherIdService;
    @Autowired
    HeadFraudService headFraudService;
    @Autowired
    BaseInfService baseInfService;
    @Autowired
    BasePhoneService basePhoneService;
    @Autowired
    BaseMarriageService baseMarriageService;
    @Autowired
    BaseResidenceService baseResidenceService;
    @Autowired
    BaseVocationService baseVocationService;
    @Autowired
    CommonSpecService commonSpecService;
    @Autowired
    HeadOtherIdHandlerService headOtherIdHandlerService;
    @Autowired
    HeadFraudService headInfHandlerService;
    @Autowired
    BaseInfoPhoneHandlerService BaseInfoPhoneHandlerService;
    @Autowired
    BaseResidenceHandlerService baseResidenceHandlerService;
    @Autowired
    BaseVocationHandlerService baseVocationHandlerService;
    @Autowired
    SmryNumReadHandlerService smryNumReadHandlerService;
    @Autowired
    SmryTradeTipsHandlerService smryTradeTipsHandlerService;
    @Autowired
    SmryRecoveredHandlerService smryRecoveredHandlerService;
    @Autowired
    SmryBadDebtService smryBadDebtService;
    @Autowired
    SmryOverdraftService smryOverdraftService;
    @Autowired
    SmryAccInfoService smryAccInfoService;
    @Autowired
    SmryCreditCardService smryCreditCardService;
    @Autowired
    SmryRepayInfoService smryRepayInfoService;
    @Autowired
    SmryNoCreditService smryNoCreditService;
    @Autowired
    SmryCommInfoService smryCommInfoService;
    @Autowired
    SmryNoFinaService smryNoFinaService;
    @Autowired
    SmryPublicService smryPublicService;
    @Autowired
    SmryQueryRecordHandlerService smryQueryRecordHandlerService;
    @Autowired
    TrsInfHandlerService trsInfHandlerService;
    @Autowired
    RltRepayBaseService rltRepayBaseService;
    @Autowired
    CtrctBaseService ctrctBaseService;
    @Autowired
    NctTrsBaseService nctTrsBaseService;
    @Autowired
    PubOwingTaxesService pubOwingTaxesService;
    @Autowired
    PubCivilService pubCivilService;
    @Autowired
    PubEnforcemenService pubEnforcemenService;
    @Autowired
    PubPenaltylService pubPenaltylService;
    @Autowired
    PubHousingFundService pubHousingFundService;
    @Autowired
    PubAllowAncService pubAllowAncService;
    @Autowired
    PubPractisingService pubPractisingService;
    @Autowired
    PubRewardService pubRewardService;
    @Autowired
    QueryRecordService queryRecordService;
    @Autowired
    BaseFieldPackageJsonService baseFieldPackageJsonService;

    /**
     * 创建xml各个信息段需要的处理的bean
     *
     * @return
     */
    @Bean
    public HandleXmlFactory createFactory() {
        HandleXmlFactory handleXmlFactory = new HandleXmlFactory();
        Map<String, HandleXmlFactoryBean> factoryBeanMap = new HashMap<>(16);
        //1.1报告头. 报告标识信息段 -OK
        createHeadInfBean(handleXmlFactory, factoryBeanMap);
        //1.2报告头. 其他身份标识信息段 -OK
        createHeadOtherIdBean(handleXmlFactory, factoryBeanMap);
        //1.3报告头. 防欺诈警示信息段 -OK
        createHeadFraudBean(handleXmlFactory, factoryBeanMap);
        //2.1基本信息-身份信息 -OK
        createBaseInfBean(handleXmlFactory, factoryBeanMap);
        //2.2基本信息-手机号码信息 -OK
        createBasePhoneBean(handleXmlFactory, factoryBeanMap);
        //2.3基本信息-配偶信息 -OK
        createBaseMarriageBean(handleXmlFactory, factoryBeanMap);
        //2.4基本信息-居住信息 -OK
        createBaseResidenceBean(handleXmlFactory, factoryBeanMap);
        //2.5基本信息-职业信息-OK
        createBaseVocationBean(handleXmlFactory, factoryBeanMap);
        //3.1信息概要-个人信用报告“数字解读” -OK
        createSmryNumRead(handleXmlFactory, factoryBeanMap);
        //3.2信息概要.-信贷交易信息提示 -OK
        createTradeTip(handleXmlFactory, factoryBeanMap);
        //3.3信息概要.-被追偿信息汇总-OK
        createRecovered(handleXmlFactory, factoryBeanMap);
        //3.4信息概要.- 呆账汇总信息段-OK
        createBadDebt(handleXmlFactory, factoryBeanMap);
        //3.5信息概要.-逾期（透支）汇总信息段
        createOverdraft(handleXmlFactory, factoryBeanMap);
        //3.6信息概要.-非循环贷账户汇总信息
        createD1AcctInfo(handleXmlFactory, factoryBeanMap);
        //3.7信息概要.-循环额度下分账户汇总
        createR4AcctInfo(handleXmlFactory, factoryBeanMap);
        //3.8信息概要.-循环贷账户信息汇总
        createR1AcctInfo(handleXmlFactory, factoryBeanMap);
        //3.9信息概要.-贷记卡账户汇总
        createR3AcctInfo(handleXmlFactory, factoryBeanMap);
        //3.10信息概要.-准贷记卡账户汇总
        createR2AcctInfo(handleXmlFactory, factoryBeanMap);
        //3.11信息概要.-相关还款责任汇总
        createRepayInfo(handleXmlFactory, factoryBeanMap);
        //3.12信息概要.-非信贷交易信息概要
        createNoCredit(handleXmlFactory, factoryBeanMap);
        //3.13信息概要.- 公共信息概要
        createCommInfo(handleXmlFactory, factoryBeanMap);
        //3.14信息概要-非金融信用交易信息概要
        createNoFina(handleXmlFactory, factoryBeanMap);
        //3.15信息概要-公开信息汇总
        createPublic(handleXmlFactory, factoryBeanMap);
        //3.16信息概要.-查询记录概要
        createSmryQueryRecord(handleXmlFactory, factoryBeanMap);
        //4.1信贷交易明细信息-被追偿信息
        createForcedTrsRecord(handleXmlFactory, factoryBeanMap);
        //4.2信贷交易明细信息-非循环贷账户
        createNoLoopTrsRecord(handleXmlFactory, factoryBeanMap);
        //4.3信贷交易明细信息-循环额度下分账户
        createLoopQuotTrsRecord(handleXmlFactory, factoryBeanMap);
        //4.4信贷交易明细信息-循环贷账户
        createLoopTrsRecord(handleXmlFactory, factoryBeanMap);
        //4.5信贷交易明细信息-贷记卡
        createCreditCardRecord(handleXmlFactory, factoryBeanMap);
        //4.6信贷交易明细信息-准贷记卡
        createPassCreditCardRecord(handleXmlFactory, factoryBeanMap);
        //4.7信贷交易明细信息-相关还款责任信息
        createRepayBase(handleXmlFactory, factoryBeanMap);
        //4.8信贷交易明细信息-授信协议信息
        createCtrctBase(handleXmlFactory, factoryBeanMap);
        //5.0非信贷交易明细信息-后付费记录
        createNctTrsBase(handleXmlFactory,factoryBeanMap);
        //6.1公共信息明细-欠税记录 cr_pub_owing_taxes
        createPubOwing(handleXmlFactory,factoryBeanMap);
        //6.2公共信息明细-民事判决记录
        createPubCivil(handleXmlFactory,factoryBeanMap);
        //6.3公共信息明细-强制执行记录 cr_pub_enforcemen
        createPubEnforcemen(handleXmlFactory,factoryBeanMap);
        //6.4公共信息明细-行政处罚记录 cr_pub_penaltyl
        createPubPenaltyl(handleXmlFactory,factoryBeanMap);
        //6.5公共信息明细-住房公积金参缴记录 cr_pub_housing_fund
        createPubHousingFund(handleXmlFactory,factoryBeanMap);
        //6.6公共信息明细-低保救助记录 cr_pub_allow_anc
        createPubAllowAnc(handleXmlFactory,factoryBeanMap);
        //6.7公共信息明细-执业资格记录 cr_pub_practising
        createPubPractising(handleXmlFactory,factoryBeanMap);
        //6.8公共信息明细-行政奖励记录
        createPubReward(handleXmlFactory,factoryBeanMap);
        //7.1 查询记录cr_query_record
        createQueryRecord(handleXmlFactory,factoryBeanMap);
        return handleXmlFactory;
    }
    /**
     * 7、查询记录cr_query_record
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createQueryRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "QUERYRECORDSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("查询记录")
                //所属信息段二类
                .secondType("")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.QUERYRECORDSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(QueryRecord.class)
                //对应的实体类
                .baseEntity(QueryRecordEntity.class)
                .service(queryRecordService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.QUERYRECORDSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 6.8公共信息明细-行政奖励记录
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubReward(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "REWARD");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("行政奖励记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.REWARDLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubReward.class)
                //对应的实体类
                .baseEntity(PubRewardEntity.class)
                .service(pubRewardService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.REWARDLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }
    /**
     * 6.7公共信息明细-执业资格记录
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubPractising(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "PRACTISING");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("执业资格记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.PRACTISINGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubPractising.class)
                //对应的实体类
                .baseEntity(PubPractisingEntity.class)
                .service(pubPractisingService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.PRACTISINGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 6.5公共信息明细-低保救助记录 cr_pub_allow_anc
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubAllowAnc(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "ALLOWANC");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("低保救助记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.ALLOWANCLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubAllowAnc.class)
                //对应的实体类
                .baseEntity(PubAllowAncEntity.class)
                .service(pubAllowAncService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.ALLOWANCLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 6.5公共信息明细-住房公积金参缴记录 cr_pub_housing_fund
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubHousingFund(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "HOUSINGFUND");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("住房公积金参缴记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.HOUSINGFUNDLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubHousingFund.class)
                //对应的实体类
                .baseEntity(PubHousingFundEntity.class)
                .service(pubHousingFundService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.HOUSINGFUNDLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 6.4公共信息明细-行政处罚记录
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubPenaltyl(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "PENALTY");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("行政处罚记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.PENALTYLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubPenaltyl.class)
                //对应的实体类
                .baseEntity(PubPenaltylEntity.class)
                .service(pubPenaltylService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.PENALTYLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 6.3公共信息明细-强制执行记录
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubEnforcemen(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "ENFORCEMENT");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("强制执行记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.ENFORCEMENTLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubEnforcemen.class)
                //对应的实体类
                .baseEntity(PubEnforcemenEntity.class)
                .service(pubEnforcemenService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.ENFORCEMENTLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }
    /**
     * 6.2公共信息明细-民事判决记录
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubCivil(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "CIVIL");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("民事判决记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.CIVILLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubCivil.class)
                //对应的实体类
                .baseEntity(PubCivilEntity.class)
                .service(pubCivilService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.CIVILLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }
    /**
     * 6.1公共信息明细-欠税记录 cr_pub_owing_taxes
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPubOwing(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "OWINGTAXES");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("公共信息明细")
                //所属信息段二类
                .secondType("欠税记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.OWINGTAXESLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(PubOwingTaxes.class)
                //对应的实体类
                .baseEntity(PubOwingTaxesEntity.class)
                .service(pubOwingTaxesService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.OWINGTAXESLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 5.0 非信贷交易信息明细-后付费记录 nct_trs_base
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createNctTrsBase(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "AFTERPAYMONEYINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("非信贷交易信息明细")
                //所属信息段二类
                .secondType("后付费记录")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.AGERAFTERPAYSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(NctTrsInfo.class)
                //对应的实体类
                .baseEntity(NctTrsBaseEntity.class)
                .service(nctTrsBaseService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.AGERAFTERPAYSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 4.8授信协议信息
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createCtrctBase(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "CONTRACTBASEINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易明细信息")
                //所属信息段二类
                .secondType("授信协议信息")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.CONTRACTBASEINFOSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(CtrctInfo.class)
                //对应的实体类
                .baseEntity(CtrctBaseEntity.class)
                .service(ctrctBaseService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.CONTRACTBASEINFOSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 4.7相关还款责任信息
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createRepayBase(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "ABOUTREPAYDUTYBASEINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易明细信息")
                //所属信息段二类
                .secondType("相关还款责任信息")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.ABOUTREPAYDUTYINFOSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(RltRepayInfo.class)
                //对应的实体类
                .baseEntity(RltRepayBaseEntity.class)
                .service(rltRepayBaseService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.ABOUTREPAYDUTYINFOSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 4.6信贷交易明细信息-准贷记卡
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPassCreditCardRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R3);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易信息明细")
                //所属信息段二类
                .secondType("准贷记卡")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.PASSCREDITCARDACCOUNTBOLS)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(PassCreditCardAcctTrsInf.class)
                //对应的实体类
                .baseEntity(TrsBaseEntity.class)
                //特殊处理
                .reportXmlBaseService(trsInfHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.PASSCREDITCARDACCOUNTBOLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 4.5信贷交易明细信息-贷记卡
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createCreditCardRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R2);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易信息明细")
                //所属信息段二类
                .secondType("贷记卡")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.CREDITCARDACCOUNTBOLS)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(CreditCardAcctTrsInf.class)
                //对应的实体类
                .baseEntity(TrsBaseEntity.class)
                //特殊处理
                .reportXmlBaseService(trsInfHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.CREDITCARDACCOUNTBOLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 4.4信贷交易明细信息-循环贷账户
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createLoopTrsRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R1);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易信息明细")
                //所属信息段二类
                .secondType("循环贷账户")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.LOOPCREDITACCOUNTBOLS)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(LoopQuotaAcctTrsInf.class)
                //对应的实体类
                .baseEntity(TrsBaseEntity.class)
                //特殊处理
                .reportXmlBaseService(trsInfHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.LOOPCREDITACCOUNTBOLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 4.3信贷交易明细信息-循环额度下分账户
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createLoopQuotTrsRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R4);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易信息明细")
                //所属信息段二类
                .secondType("循环额度下分账户")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.LOOPQUOTAACCOUNTBOLS)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(LoopQuotaAcctTrsInf.class)
                //对应的实体类
                .baseEntity(TrsBaseEntity.class)
                //特殊处理
                .reportXmlBaseService(trsInfHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.LOOPQUOTAACCOUNTBOLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 4.1信贷交易明细信息-被追偿信息
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createForcedTrsRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_C1);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易信息明细")
                //所属信息段二类
                .secondType("被追偿信息")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.FORCEDREPAYINFOBOLS)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(ForcedAcctTrsInf.class)
                //对应的实体类
                .baseEntity(TrsBaseEntity.class)
                //特殊处理
                .reportXmlBaseService(trsInfHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.FORCEDREPAYINFOBOLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 4.2信贷交易明细信息-非循环贷信息
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createNoLoopTrsRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_D1);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信贷交易信息明细")
                //所属信息段二类
                .secondType("非循环贷账户")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.NOLOOPCREDITACCOUNTBOLS)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(NoLoopAcctTrsInf.class)
                //对应的实体类
                .baseEntity(TrsBaseEntity.class)
                //特殊处理
                .reportXmlBaseService(trsInfHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.NOLOOPCREDITACCOUNTBOLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 3.16信息概要.-查询记录概要
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createSmryQueryRecord(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {

        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("查询记录概要")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.QUERYRECORDSMRYBO)
                //node节点处理类型
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(SmryQueryRecord.class)
                //对应的实体类
                .baseEntity(SmryQueryRecordEntity.class)
                //特殊处理
                .reportXmlBaseService(smryQueryRecordHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.QUERYRECORDSMRYBO, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.15 公开信息概要
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createPublic(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "PUBLICINFOSMRY");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("公开信息概要")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.PUBLICINFOSMRYLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(SmryPublic.class)
                //对应的实体类
                .baseEntity(SmryPublicEntity.class)
                .service(smryPublicService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.PUBLICINFOSMRYLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.14 非金融信用交易信息概要
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createNoFina(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "NOFINASMRY");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("非金融信息交易信息概要")
                //所属信息段三类
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.NOFINASMRYLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(SmryNoFina.class)
                //对应的实体类
                .baseEntity(SmryNoFinaEntity.class)
                .service(smryNoFinaService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.NOFINASMRYLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.12 公共信息概要
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createCommInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "COMMINFOSMRY");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("公共信息概要")
                //所属信息段三类
                .thirdType("公共信息汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.COMMINFOSMRYLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(SmryComm.class)
                //对应的实体类
                .baseEntity(SmryCommInfoEntity.class)
                .service(smryCommInfoService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.COMMINFOSMRYLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 信息概要. 3.11 非信贷交易信息概要
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createNoCredit(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "POSTPAYSMRY");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("非信贷交易信息概要")
                //所属信息段三类
                .thirdType("后付费业务欠费信息汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.POSTPAYSMRYLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(SmryNoCredit.class)
                //对应的实体类
                .baseEntity(SmryNoCreditEntity.class)
                .service(smryNoCreditService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.POSTPAYSMRYLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.11 相关还款责任汇总
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createRepayInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "REPAYMENTINFOSMRY");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易授信及负债信息概要")
                //所属信息段三类
                .thirdType("贷记卡账户汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.REPAYINFOSMRYLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(SmryRepay.class)
                //对应的实体类
                .baseEntity(SmryRepayInfoEntity.class)
                .service(smryRepayInfoService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.REPAYINFOSMRYLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.10 准贷记卡账户汇总
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createR2AcctInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R2);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易授信及负债信息概要")
                //所属信息段三类
                .thirdType("贷记卡账户汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.ZDEBITCARDACCSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(SmryCreditCard.class)
                //对应的实体类
                .baseEntity(SmryCreditCardEntity.class)
                .service(smryCreditCardService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.ZDEBITCARDACCSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.9 贷记卡账户汇总
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createR3AcctInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R3);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易授信及负债信息概要")
                //所属信息段三类
                .thirdType("贷记卡账户汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.DEBITCARDACCSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(SmryCreditCard.class)
                //对应的实体类
                .baseEntity(SmryCreditCardEntity.class)
                .service(smryCreditCardService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.DEBITCARDACCSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.8 循环贷账户信息汇总
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createR1AcctInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R1);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易授信及负债信息概要")
                //所属信息段三类
                .thirdType("循环贷账户信息汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.CYCLICALLOANSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(SmryAccInfo.class)
                //对应的实体类
                .baseEntity(SmryAccInfoEntity.class)
                .service(smryAccInfoService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.CYCLICALLOANSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.7信息概要.-循环额度下分账户汇总
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createR4AcctInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_R4);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易授信及负债信息概要")
                //所属信息段三类
                .thirdType("循环额度下分账户汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.CYBRANCHACCSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(SmryAccInfo.class)
                //对应的实体类
                .baseEntity(SmryAccInfoEntity.class)
                .service(smryAccInfoService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.CYBRANCHACCSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.6信息概要.-非循环贷账户汇总信息
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createD1AcctInfo(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        //字段名
        paramMap.put(BaseConsts.ACC_TYPE_ATTRIBUTE, "accType");
        //账户类型值
        paramMap.put(BaseConsts.ACC_TYPE_KEY, BaseConsts.ACC_TYPE_D1);
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易授信及负债信息概要")
                //所属信息段三类
                .thirdType("非循环贷账户汇总信息")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.NONCYCLICALSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(SmryAccInfo.class)
                //对应的实体类
                .baseEntity(SmryAccInfoEntity.class)
                .service(smryAccInfoService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.NONCYCLICALSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 3.5信息概要.-逾期（透支）汇总信息段
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createOverdraft(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "OVERDRAFTSUMSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("逾期（透支）汇总信息段")
                //所属信息段三类 --暂无
                .thirdType("被追偿信息汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.OVERDRAFTSUMSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(Overdraft.class)
                //对应的实体类
                .baseEntity(SmryOverdraftEntity.class)
                .service(smryOverdraftService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.OVERDRAFTSUMSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 2.3 信息概要.- 呆账汇总信息段
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createBadDebt(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易违约信息概要")
                //所属信息段三类 --暂无
                .thirdType("被追偿信息汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.BADDEBTSSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(SmryBadDebt.class)
                //对应的实体类
                .baseEntity(SmryBadDebtEntity.class)
                //对应xml信息段的额外处理的service
                .service(smryBadDebtService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //特殊赋值信息段
                .specService(commonSpecService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.BADDEBTSSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要. 2.2 被追偿信息汇总
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createRecovered(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易违约信息概要")
                //所属信息段三类 --暂无
                .thirdType("被追偿信息汇总")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.RECOVEREDINFOSUMSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(SmryRecovered.class)
                //对应的实体类
                .baseEntity(SmryRecoveredEntity.class)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //对应xml信息段的额外处理的service
                .reportXmlBaseService(smryRecoveredHandlerService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.RECOVEREDINFOSUMSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 信息概要. 2.1 信贷交易信息提示
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createTradeTip(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("信贷交易信息提示")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.CREDITTRADETIPSSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(SmryTradeTips.class)
                //对应的实体类
                .baseEntity(SmryTradeTipsEntity.class)
                //对应xml信息段的额外处理的service
                .reportXmlBaseService(smryTradeTipsHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.CREDITTRADETIPSSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 信息概要-个人信用报告“数字解读
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createSmryNumRead(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("信息概要")
                //所属信息段二类
                .secondType("个人信用报告-数字解读")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.GRADEINFOSMRY)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_COMPOSE)
                //对应的xml的node节点名
                .modelBean(SmryNumRead.class)
                .baseEntity(SmryNumReadEntity.class)
                //对应xml信息段的额外处理的service
                .reportXmlBaseService(smryNumReadHandlerService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.GRADEINFOSMRY, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


    /**
     * 基本信息-职业信息
     *
     * @param handleXmlFactory 处理xml工厂类
     * @param factoryBeanMap   存放工厂类的Map集合
     */
    private void createBaseVocationBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "VOCATIONINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("基本信息")
                //所属信息段二类
                .secondType("职业信息")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.VOCATIONINFOSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(BaseVocation.class)
                //实体类
                .baseEntity(BaseVocationEntity.class)
                //保存service
                .service(baseVocationService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.VOCATIONINFOSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 基本信息-居住信息
     *
     * @param handleXmlFactory 处理xml工厂类
     * @param factoryBeanMap   存放工厂类的Map集合
     */
    private void createBaseResidenceBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "RESIDENCEINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("基本信息")
                //所属信息段二类
                .secondType("居住信息")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.RESIDENCEINFOSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(BaseResidence.class)
                //实体类
                .baseEntity(BaseResidenceEntity.class)
                //保存service
                .service(baseResidenceService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                //额外参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.RESIDENCEINFOSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 基本信息-配偶信息
     *
     * @param handleXmlFactory 处理xml工厂类
     * @param factoryBeanMap   存放工厂类的Map集合
     */
    private void createBaseMarriageBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("基本信息")
                //所属信息段二类
                .secondType("配偶信息")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.MARRIAGEINFOSG)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(BaseMarriage.class)
                //信息段对应的实体类
                .baseEntity(BaseMarriageEntity.class)
                //保存service
                .service(baseMarriageService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.MARRIAGEINFOSG, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 基本信息-手机号码信息
     *
     * @param handleXmlFactory 处理xml工厂类
     * @param factoryBeanMap   存放工厂类的Map集合
     */
    private void createBasePhoneBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "TELEPHONEINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("基本信息")
                //所属信息段二类
                .secondType("手机号码信息")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.TELEPHONEINFOSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(BasePhone.class)
                .baseEntity(BasePhoneEntity.class)
                .service(basePhoneService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //额外参数
                .paramMap(paramMap)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.TELEPHONEINFOSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 基本信息-身份信息
     *
     * @param handleXmlFactory 处理xml工厂类
     * @param factoryBeanMap   存放工厂类的Map集合
     */
    private void createBaseInfBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("基本信息")
                //所属信息段二类
                .secondType("身份信息")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.BASEINFO)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(BaseInf.class)
                //信息段对应的实体类
                .baseEntity(BaseInfEntity.class)
                //保存service
                .service(baseInfService)
                //特殊赋值信息段
                .specService(commonSpecService)
                //拼接json字符串
                .baseFieldPackageJsonService(baseFieldPackageJsonService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.BASEINFO, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 防欺诈警示信息
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createHeadFraudBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("报告头")
                //所属信息段二类
                .secondType("防欺诈警示信息")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.FRAUD)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(HeadFraud.class)
                //信息段对应的实体类
                .baseEntity(HeadFraudEntity.class)
                //保存service
                .service(headInfHandlerService)
                //特殊赋值信息段
                .specService(commonSpecService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.FRAUD, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 报告头. 报告标识信息段
     *
     * @param handleXmlFactory 处理xml工厂类
     * @param factoryBeanMap   集合
     */
    private void createHeadInfBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("报告头")
                //所属信息段二类
                .secondType("报告标识信息段")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.HEADBO)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_NORMAL)
                //对应的xml的node节点名
                .modelBean(HeadInfo.class)
                //信息段对应的实体类
                .baseEntity(CrHeadInfEntity.class)
                //保存service
                .service(crHeadInfService)
                //特殊赋值信息段
                .specService(commonSpecService)
                .build();
        factoryBeanMap.put(XmlNodeConsts.HEADBO, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }

    /**
     * 报告头. 其他身份标识信息段
     *
     * @param handleXmlFactory
     * @param factoryBeanMap
     */
    private void createHeadOtherIdBean(HandleXmlFactory handleXmlFactory, Map<String, HandleXmlFactoryBean> factoryBeanMap) {
        //额外参数
        Map<String, String> paramMap = new HashMap<>(16);
        paramMap.put(BaseConsts.NODE_LIST_NAME, "TELEPHONEINFOSG");
        HandleXmlFactoryBean handleXmlFactoryBean = HandleXmlFactoryBean.builder()
                //所属信息段分类
                .firstType("报告头")
                //所属信息段二类
                .secondType("其他身份标识信息段")
                //所属信息段三类 --暂无
                .thirdType("")
                //对应的xml的node节点名
                .xmlNodeName(XmlNodeConsts.OTHERIDSGLS)
                //node节点是否是循环列表
                .nodeType(BaseConsts.NODE_TYPE_LIST)
                //对应的xml的node节点名
                .modelBean(HeadOther.class)
                //特殊赋值信息段
                .specService(commonSpecService)
                //实体类
                .baseEntity(CrHeadOtherIdEntity.class)
                //对应处理的service
                .service(crHeadOtherIdService)
                //其它参数
                .paramMap(paramMap)
                .build();
        factoryBeanMap.put(XmlNodeConsts.OTHERIDSGLS, handleXmlFactoryBean);
        handleXmlFactory.setFactoryBeanMap(factoryBeanMap);
    }


}
