package com.kexun.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.kexun.common.utils.Result;
import com.kexun.entity.*;
import com.kexun.model.ro.FiledTemplateRO;
import com.kexun.model.ro.FiledTemplateUpdateRO;
import com.kexun.model.vo.FiledTemplateVO;
import com.kexun.service.BusinessService;
import com.kexun.service.FieldTemplateService;
import lombok.extern.java.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;
//字段模版

@RestController
@RequestMapping("/admin/fieldtemplate")
@Log
public class FieldTemplateController {

    @Autowired
    private FieldTemplateService fieldTemplateService;


    /**
     * 获取字段模版信息
     *
     * @return
     */
    @GetMapping("fieldTemplateList")
    public Result fieldTemplateList() {
        JSONObject resJson = new JSONObject();
        List<FieldTemplateEntity> list = fieldTemplateService.list();
        resJson.put("field_template_list", list);
        return Result.success("ok", resJson);
    }

    /**
     * 获取字段模板列表分页信息
     *
     * @param filedTemplateRO
     * @return
     */
    @GetMapping("list")
    public Result list(FiledTemplateRO filedTemplateRO) {
        Result result = new Result();
        IPage<FieldTemplateEntity> fieldTemplateEntityIPage = fieldTemplateService.listPage(filedTemplateRO);
        result.setData(fieldTemplateEntityIPage);
        return result;
    }

    @RequestMapping("/findAll")
    @ResponseBody
    public Result findAll(@RequestParam int pageNum){
        int pageSize = 10;
        PageHelper.startPage(pageNum, pageSize);//设置分页信息
        List<FieldTemplateEntity> list = fieldTemplateService.selectPage();
        PageInfo pageInfo=new PageInfo(list);
        System.out.println(pageInfo);
        JSONObject resJson = new JSONObject();

        resJson.put("field_template_list", pageInfo);

        return Result.success("ok", resJson);
    }



    /**
     * 字段模板详情
     *
     * @param id
     * @return
     */
    @GetMapping("detail")
    public Result detail(@RequestParam Long id) {
        Result result = new Result();
        if (StringUtils.isEmpty(id)) {
            return Result.error("-1", "字段定义的ID不能为空");
        }
        FiledTemplateVO detail = fieldTemplateService.detail(id);
        result.setData(detail);
        return result;
    }

    /**
     * 保存
     *
     * @param filedTemplateUpdateRO
     * @return
     */
    @PostMapping("save")
    public Result save(@RequestBody FiledTemplateUpdateRO filedTemplateUpdateRO) {
        Result result = new Result();
        fieldTemplateService.save(filedTemplateUpdateRO);
        return result;
    }

    /**
     * 修改
     *
     * @param filedTemplateUpdateRO
     * @return
     */
    @PostMapping("update")
    public Result update(@RequestBody FiledTemplateUpdateRO filedTemplateUpdateRO) {
        Result result = new Result();
        if (null != filedTemplateUpdateRO.getId()) {
            fieldTemplateService.saveOrUpdate(filedTemplateUpdateRO);
        } else {
            return Result.error(-1, "id不存在");
        }
        return result;
    }


    /**
     * 基础字段启用/停用
     *
     * @param id     主键
     * @param status 状态
     * @return
     */
    @PostMapping("on-off")
    public Result onOff(@RequestParam Long id, @RequestParam String status) {
        if (StringUtils.isEmpty(id)) {
            return Result.error("-1", "字段定义的ID不能为空");
        }
        if (StringUtils.isEmpty(status)) {
            return Result.error("-1", "开启/停用状态不能为空");
        }
        fieldTemplateService.updateOnOff(id, status);
        return Result.success();

    }

    /**
     * 删除
     *
     * @param id 主键
     * @return
     */
    @DeleteMapping("delete")
    public Result delete(@RequestParam Long id) {
        if (StringUtils.isEmpty(id)) {
            return Result.error("-1", "字段定义的ID不能为空");
        }
        System.out.println(id);
        fieldTemplateService.delete(id);
        return Result.success();
    }

}
