package com.kexun.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.kexun.entity.BusInfoModifyHis;
import com.kexun.entity.CooperatorInfo;
import com.kexun.entity.FieldDefineEntity;
import com.kexun.entity.FieldTemplateEntity;
import com.kexun.hander.PageBean;
import com.kexun.mapper.BusInfoModifyHisMapper;
import com.kexun.mapper.FieldDefineMapper;
import com.kexun.model.ro.FiledRO;
import com.kexun.model.ro.FiledUpdateRO;
import com.kexun.service.FieldDefineService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.kexun.utils.PageUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 字段定义表 服务实现类
 * </p>
 *
 * @author lgs
 * @since 2023-06-21
 */
@Service
public class FieldDefineServiceImpl extends ServiceImpl<FieldDefineMapper, FieldDefineEntity> implements FieldDefineService {

    @Autowired
    FieldDefineService fieldDefineService;
    @Autowired
    private FieldDefineMapper fieldDefineMapper;

    /**
     * 分页查询字段定义
     *
     * @param filedRO
     * @return
     */
    @Override
    public IPage<FieldDefineEntity> listPage(FiledRO filedRO) {
        PageBean<FieldDefineEntity> page = new PageBean<>(PageUtils.getPageNo(filedRO.getPageNo()), PageUtils.getPageSize(filedRO.getPageSize()));
        QueryWrapper queryWrapper = new QueryWrapper();
        if (!StringUtils.isEmpty(filedRO.getCategory())) {
            queryWrapper.eq("category", filedRO.getCategory());
        }
        if (!StringUtils.isEmpty(filedRO.getFieldNo())) {
            queryWrapper.eq("field_no", filedRO.getFieldNo());
        }
        if (!StringUtils.isEmpty(filedRO.getNameZh())) {
            queryWrapper.eq("name_zh", filedRO.getNameZh());
        }
        IPage<FieldDefineEntity> pageList = fieldDefineMapper.selectPage(page, queryWrapper);
        return pageList;
    }

    /**
     * 根据一级分类查询字段定义信息
     * @param oneLevel
     * @return
     */
    @Override
    public List<FieldDefineEntity> listFieldInfoByLevel(String oneLevel){
        QueryWrapper queryWrapper = new QueryWrapper();
        if (!StringUtils.isEmpty(oneLevel)) {
            queryWrapper.eq("one_level", oneLevel);
        }
        List<FieldDefineEntity> list = super.list(queryWrapper);
        return list;
    }

    public List<FieldDefineEntity> selectPage() {
//        System.out.println("aaa");
        String cat = "1";
        List<FieldDefineEntity> l = fieldDefineMapper.selectAll(cat);
        return l;
    }

    public List<FieldDefineEntity> selectPage2() {
//        System.out.println("aaa");
        String cat = "2";
        List<FieldDefineEntity> l = fieldDefineMapper.selectAll(cat);
        return l;
    }

    /**
     * 保存或者修改字段定义
     * @param filedUpdateRO
     */
    @Override
    public void saveOrUpdate(FiledUpdateRO filedUpdateRO) {
        Long id = filedUpdateRO.getId();
        FieldDefineEntity defineEntity = getById(id);
        FieldDefineEntity fieldDefineEntity = new FieldDefineEntity();

        if (null != defineEntity) {
            BeanUtils.copyProperties(filedUpdateRO,fieldDefineEntity);

            updateById(fieldDefineEntity);
        }else {
            filedUpdateRO.setCategory("2");
            long time1 = System.currentTimeMillis();
            filedUpdateRO.setFieldNo(Long.toString(time1));
            BeanUtils.copyProperties(filedUpdateRO,fieldDefineEntity);
            save(fieldDefineEntity);
        }
    }

    /**
     * 修改状态
     * @param id 主键
     * @param status 状态
     */
    @Override
    public void updateOnOff(Long id,String status){
        fieldDefineMapper.updateStatus(id,status);
    }

    @Override
    public FieldDefineEntity findByID(long id) {
        QueryWrapper<FieldDefineEntity> wrapper=new QueryWrapper<FieldDefineEntity>().eq("id",id);
        return getOne(wrapper);
    }

}
