package com.kexun.task;

import com.kexun.constant.ReportConsts;
import com.kexun.entity.ReportInfo;
import com.kexun.enums.ReportStatusEnum;
import com.kexun.model.ReportStruct;
import com.kexun.model.Request;
import com.kexun.service.ReportInfoService;
import com.kexun.service.XmlFileHandlerService;
import com.kexun.service.impl.ReportInfoServiceImpl;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Optional;

/**
 * Description: 定时任务：
 * 读取指定目录下xml文件，进行解密，解析xml报文，然后记录到数据库表中report_info
 *
 * @author lgs
 * @date 2023/05/08
 */
@Component
@Slf4j
public class ReadXmlFileJobHandler {

    @Autowired
    XmlFileHandlerService xmlFileHandlerService;

    @Autowired
    ReportInfoService reportInfoService;

    /**
     * 处理思路
     * 1、读取指定目录下xml文件
     * 2、解析xml文件，保存到表report_info。
     * 3、判断是否重复，读取完之后移动读取的文件到其他目录
     *
     * @throws Exception
     */
    @XxlJob("readXmlFileJobHandler")
    public void readXmlFile() throws Exception {
        log.info("定时任务1开始读取文件");
        //读取xml文件
        ReportStruct reportStruct = xmlFileHandlerService.readXmlFile();
        //保存到report_info信息表
        ReportInfo reportInfo = new ReportInfo();
        //获取请求信息段
        Request request = reportStruct.getRequest();
        //业务申请ID
        reportInfo.setBusinessId(Long.valueOf(request.getId()));
        //业务申请编号
        reportInfo.setBusinessNum(request.getBusinessNum());
        //客户编号
        reportInfo.setCustomerNum(request.getCustomerNum());
        //客户姓名
        reportInfo.setCustomerName(request.getCustomerName());
        //合作方编号
        reportInfo.setCoopBusinessNum(request.getCoopBusinessNum());
        //产品编号
        reportInfo.setProductNum(request.getProductNum());
        //扩展信息
        reportInfo.setExtend(request.getExtend());
        //报文体
        reportInfo.setBody(reportStruct.getResponseBody());
        //征信查询结果
        reportInfo.setResultCode(reportStruct.getResponseHeader().getResultCode());
        //征信查询结果描述
        reportInfo.setResultDesc(reportStruct.getResponseHeader().getResultMsg());
        //待解析状态
        String resultCode = reportStruct.getResponseHeader().getResultCode();
        String resultMsg = reportStruct.getResponseHeader().getResultMsg();
        if (ReportConsts.RETURN_CODE_0.equals(resultCode)) {
            if (ReportConsts.RESULT_MSG_SUCC_HAVE.equals(resultMsg)) {
                //查询成功，且有报告
                reportInfo.setStatus(ReportStatusEnum.NO_PRASE.getValue());
            } else if (ReportConsts.RESULT_MSG_SUCC_NOHAVE.equals(resultMsg)) {
                //查询成功，无报告
                reportInfo.setStatus(ReportStatusEnum.NO_REPORT.getValue());
            } else if (ReportConsts.RESULT_MSG_FAIL.equals(resultMsg)) {
                //查询失败
                reportInfo.setStatus(ReportStatusEnum.QUERY_FAIL.getValue());
            }
        } else if (ReportConsts.RETURN_CODE_1.equals(resultCode)) {
            reportInfo.setStatus(ReportStatusEnum.ERROR.getValue());
        }
        //文件名
        reportInfo.setFileName(reportStruct.getFileName());
        //保存报文信息
        reportInfoService.saveReportInfo(reportInfo);
    }
}
