package com.kexun.task;

import com.kexun.entity.ReportInfo;
import com.kexun.enums.ReportStatusEnum;
import com.kexun.exception.RRException;
import com.kexun.model.ro.ReportInfoRO;
import com.kexun.service.ReportInfoService;
import com.kexun.service.xml.ParseHandleService;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.Base64;
import java.util.List;
import java.util.zip.GZIPInputStream;

/**
 * Description:征信报文解析
 *
 * @author lgs
 * @date 2023/05/11
 */
@Component
@Slf4j
public class ReportParseJobHandler {

    @Autowired
    ParseHandleService parseHandleService;

    @Autowired
    ReportInfoService reportInfoService;

    /**
     *  报文解密，解析
     *  思路：
     *  1、从数据库表report_info中获取未处理的数据，进行解析
     *  2、解密报文体
     *  3、解密出来以后，根据各个信息段，进行各数据段的保存
     *
     * @throws Exception
     */
    @XxlJob("reportParseJobHandler")
    public void parse() throws Exception{

        ReportInfoRO reportInfoRO = new ReportInfoRO();
        reportInfoRO.setStatus(ReportStatusEnum.NO_PRASE.getValue());
        List<ReportInfo> reportInfos = reportInfoService.listReportInfo(reportInfoRO);
        for (ReportInfo reportInfo : reportInfos) {
            //body报文体是Base64位，先解码 再解压
            String body = reportInfo.getBody();
            if (!StringUtils.isEmpty(body)){
                byte[] decode = Base64.getDecoder().decode(body);
                ByteArrayOutputStream out = new ByteArrayOutputStream();
                ByteArrayInputStream in = new ByteArrayInputStream(decode);
                try {
                    GZIPInputStream ungzip = new GZIPInputStream(in);
                    byte[] buffer = new byte[256];
                    int n;
                    while ((n = ungzip.read(buffer)) >= 0) {
                        out.write(buffer, 0, n);
                    }
                } catch (IOException e) {
                    log.error("解压出现错误");
                }
                String xmlContext = out.toString("utf-8");
                log.info(xmlContext);
                try {
                    //解析xml文件
                    parseHandleService.parseHandle(xmlContext);
                    //修改解析报文信息的状态
                    reportInfo.setStatus(ReportStatusEnum.PRASE_FINISH.getValue());
                    //解析成功 状态为已解析
                    reportInfoService.updateReportInfo(reportInfoRO);
                }catch (Exception e){
                    e.printStackTrace();
                    //解析失败，状态修改成失败
                    reportInfo.setStatus(ReportStatusEnum.QUERY_FAIL.getValue());
                    log.error("解析出现异常，异常信息如下:{}",e.getStackTrace());
                    new RRException("解析出现异常,异常信息："+e.getMessage(), -1);
                }

            }else {
                log.info("获取到的解析内容为空，不做处理");
            }
        }
    }
}
