package com.kexun.utils;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.dom4j.*;
import org.springframework.beans.factory.annotation.Value;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Description: 解析xml的工具类
 *
 * @author lgs
 * @date 2023/05/29
 */
public class ParseXmlUtils {

    /**
     * xml报文里，单笔记录也需要转成List的节点
     */
    private static List convertListPath = Arrays.asList("TELEPHONEINFOSG","RESIDENCEINFOSG","VOCATIONINFOSG","OTHERTAGDECLARE","SCOREEXPLAINCODELS","CREDITTIPSINFO","RECORINFOSUMSG","OVERDRAFTSUMSG","REPAYMENTINFOSMRY","POSTPAYSMRY","COMMINFOSMRY","NOFINASMRY","PUBLICINFOSMRY","NOFINASMRY","PUBLICINFOSMRY","FIVEYEARHISRPYINFOSG","SPECIALTRADEBASEINFOSG","SPECIALEVENTBASEINFOSG","BIGQUOTABASELNFOSG","CONTRACTBASEINFOSG","AFTERPAYMONEYINFOSG","OWINGTAXES","CIVIL","ENFORCEMENT","PENALTY","HOUSINGFUND","ALLOWANC","PRACTISING","REWARD","QUERYRECORDSG");
    /**
     * 根据节点名称获取节点要素
     *
     * @param rootElement
     * @param key
     * @return
     */
    public static HashMap<String, Object> getElements(Element rootElement, String key) {
        //存放xml节点元素的map集合
        HashMap<String, Object> mapEle = new HashMap<>();
        Element subElement = rootElement.element(key);
        Map<String, Object> requestMap = new HashMap<>(16);
        if (subElement.elements().size() > 0) {
            for (Element element : subElement.elements()) {
                String name = element.getName();
                String value = element.getText();
                requestMap.put(name, value);
            }
            mapEle.put(key, requestMap);
        } else {
            mapEle.put(key, subElement.getText());
        }

        return mapEle;
    }

    /**
     * xml字符串转json字符串
     * xml的根元素是不会遍历出来，而是直接作为对象的
     * 如<info><ab>ss</ab></info> = {"ab":"ss"}  如果带上根元素即为{"info":{"ab":"ss"}}}
     *
     * @param xmlStr
     * @return
     */
    public static JSONObject xmlToJson(String xmlStr) {
        JSONObject jo = new JSONObject();
        try {
            Document doc = DocumentHelper.parseText(xmlStr);
            JSONObject json = new JSONObject();
            dom4jJson(doc.getRootElement(), json);
            jo = json;
        } catch (DocumentException e) {
            e.printStackTrace();
        }
        return jo;
    }

    /**
     * xml文档对象转json对象
     *
     * @param element
     * @param json
     */
    public static void dom4jJson(Element element, JSONObject json) {
        // 如果是属性
        for (Object o : element.attributes()) {
            Attribute attr = (Attribute) o;
            if (!isEmpty(attr.getValue())) {
                json.put("@" + attr.getName(), attr.getValue());
            }
        }
        @SuppressWarnings("unchecked")
        List<Element> chdEl = element.elements();
        // 如果没有子元素,只有一个值
        if (chdEl.isEmpty() && !isEmpty(element.getText())) {
            json.put(element.getName(), element.getText());
        }
        // 有子元素
        for (Element e : chdEl) {
            // 子元素也有子元素
            if (!e.elements().isEmpty()) {
                JSONObject chdjson = new JSONObject();
                dom4jJson(e, chdjson);
                Object o = json.get(e.getName());
                if (o != null) {
                    JSONArray jsona = null;
                    // 如果此元素已存在,则转为jsonArray
                    if (o instanceof JSONObject) {
                        JSONObject jsono = (JSONObject) o;
                        json.remove(e.getName());
                        jsona = new JSONArray();
                        jsona.add(jsono);
                        jsona.add(chdjson);
                    }
                    if (o instanceof JSONArray) {
                        jsona = (JSONArray) o;
                        jsona.add(chdjson);
                    }
                    json.put(e.getName(), jsona);
                } else {
                    if (!chdjson.isEmpty()) {
                        if (convertListPath.contains(e.getName())){
                            JSONArray  jsonArray = new JSONArray();
                            jsonArray.add(chdjson);
                            json.put(e.getName(), jsonArray);
                        }else{
                            json.put(e.getName(), chdjson);
                        }

                    }
                }
            } else {// 子元素没有子元素
                for (Object o : element.attributes()) {
                    Attribute attr = (Attribute) o;
                    if (!isEmpty(attr.getValue())) {
                        json.put("@" + attr.getName(), attr.getValue());
                    }
                }
                json.put(e.getName(), e.getText());
            }
        }
    }

    /**
     * 判断是否为空
     * @param str
     * @return
     */
    public static boolean isEmpty(String str) {
        if (str == null || str.trim().isEmpty() || "null".equals(str)) {
            return true;
        }
        return false;
    }

}
